@@ -12,8 +12,10 @@ import numpy as np
 import pandas as pd
 import seaborn as sns
 from IPython.display import display
+from IPython.display import Image
 from matplotlib import pyplot as plt
 
+
 # Local packages
 from napoleontoolbox.tools.time_tools import _parse_date, parser_date
 from napoleontoolbox.tools.analyze_tools import roll_corr
@@ -280,6 +282,8 @@ class MarketAnalyzer:
 
         display(style)
 
+
+
     def get_perf(self):
         """ Get asset performances.
 
@@ -291,7 +295,7 @@ class MarketAnalyzer:
         """
         return self.base * self.df / self.df.iloc[0, :].values
 
-    def plot_perf(self, title='Performances', ax=None, show=True,saving_png_path = None,saving_png_perf_path = None, **kwargs):
+    def plot_perf(self, title='Performances', ax=None, show=True,saving_png_path = None, **kwargs):
         """ Plot asset performances.
 
         Parameters
@@ -315,9 +319,6 @@ class MarketAnalyzer:
 
         if not df.empty:
             df.plot(ax=ax, title=title, **kwargs)
-            if saving_png_perf_path is not None:
-                fig = ax.get_figure()
-                fig.savefig(saving_png_perf_path)
 
 
         if show:
