@@ -111,8 +111,12 @@ class ParallelRunResultAnalyzer():
             for col in results_df.columns:
                 if col != 'Date':
                     run_json_string=signal_utility.recover_to_sql_column_format(col)
-                    params = json.loads(run_json_string)
-                    #salty = hashlib.sha256(run_json_string)
+                    try:
+                        params = json.loads(run_json_string)
+                    except json.decoder.JSONDecodeError as e:
+                        print('trouble generating seed')
+                        print(e)
+                        continue
                     salty =str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
                     if 'transaction_costs' in params.keys():
                         transacs = str(params['transaction_costs'])
@@ -189,7 +193,12 @@ class ParallelRunResultAnalyzer():
             for col in results_df.columns:
                 if col != 'Date':
                     run_json_string=signal_utility.recover_to_sql_column_format(col)
-                    params = json.loads(run_json_string)
+                    try:
+                        params = json.loads(run_json_string)
+                    except json.decoder.JSONDecodeError as e:
+                        print('trouble generating seed')
+                        print(e)
+                        continue
                     #salty = hashlib.sha256(run_json_string)
                     salty =str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
                     if 'transaction_costs' in params.keys():
