@@ -16,7 +16,7 @@ import json
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying = None, freqly_pkl_file_name_sufffix='freqly_candels.pkl', local_root_directory='../data/', user = 'napoleon',nb_items_per_year=252):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying = None, freqly_pkl_file_name_sufffix='freqly_candels.pkl', local_root_directory='../data/', user = 'napoleon',period=252):
         super().__init__()
         self.freqly_pkl_file_name_sufffix=freqly_pkl_file_name_sufffix
         self.underlying = underlying
@@ -27,7 +27,7 @@ class AbstractRunner(ABC):
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
         self.running_date = running_date
         self.starting_date = starting_date
-        self.nb_items_per_year = nb_items_per_year
+        self.period = period
 
     @abstractmethod
     def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs):
@@ -77,13 +77,19 @@ class SimpleSignalRunner(AbstractRunner):
 
 
         freqly_df = signal_utility.reconstitute_signal_perf(data = freqly_df, transaction_cost = transaction_costs , normalization = normalization)
-        sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period= self.nb_items_per_year, from_ret=True)
-        sharpe_under = metrics.sharpe(freqly_df['close_return'].dropna(), period= self.nb_items_per_year, from_ret=True)
+        sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period= self.period, from_ret=True)
+        sharpe_under = metrics.sharpe(freqly_df['close_return'].dropna(), period= self.period, from_ret=True)
         freqly_df = freqly_df.dropna()
         print('underlying sharpe')
         print(sharpe_under)
         print('strat sharpe')
         print(sharpe_strat)
+        print('size before dropping duplicates')
+        print(freqly_df.shape)
+        freqly_df = freqly_df.drop_duplicates()
+        print('size after dropping duplicates')
+        print(freqly_df.shape)
+
         saver.saveAll(saving_key, freqly_df)
         print('save done')
         return
