@@ -842,24 +842,27 @@ def rolling_allocation(f, X, n=252, s=63, ret=True, drift=True, filtering_thresh
     return portfolio, w_mat
 
 
-def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=True, ensembling_model = 'other', period = 252, **kwargs):
+def rolling_ensembling(X, w_mat_predictors_list, w_mat_target=None, n=252, s=63,ret=True, ensembling_model = 'other', period = 252, display_slice = True, **kwargs):
+    ## w_mat_target is there only for supervised learning
     assert len(w_mat_predictors_list) > 1
     X = pd.DataFrame(X).fillna(method='ffill')
     if ret:
         X_ = X.pct_change()
     else:
         X_ = X
-    if ensembling_model == 'min_sharpe':
+    if ensembling_model == 'det_max_sharpe':
         to_apply = lambda my_df : pd.DataFrame(my_df).fillna(0)
         w_mat_predictors_list = list(map(to_apply, w_mat_predictors_list))
         idx = w_mat_predictors_list[0].index
-        w_mat = pd.DataFrame(index=idx, columns=w_mat_target.columns)
+        cols = w_mat_predictors_list[0].columns
+        w_mat = pd.DataFrame(index=idx, columns=cols)
+        #w_mat = pd.DataFrame(index=idx, columns=w_mat_target.columns)
         portfolio = pd.Series(100., index=idx, name='portfolio')
         roll = rolling._EnsemblingRollingMechanism(idx, n=n, s=s)
-        for slice_n, slice_s in roll():
+        for slice_n, slice_s, _ in roll():
             train_ret = X_.loc[slice_n].copy()
-            train_forward_looking = w_mat_target.loc[slice_n].copy()
-            test_forward_looking = w_mat_target.loc[slice_s].copy()
+            #train_forward_looking = w_mat_target.loc[slice_n].copy()
+            #test_forward_looking = w_mat_target.loc[slice_s].copy()
 
             to_train = lambda my_df: my_df.loc[slice_n].copy()
             to_test = lambda my_df: my_df.loc[slice_s].copy()
@@ -882,7 +885,105 @@ def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=T
             portfolio.loc[slice_s] = portfolio.loc[roll.d] * perf.flatten()
         w_mat = w_mat.fillna(method='ffill').fillna(0.)
         return portfolio, w_mat
-    elif ensembling_model == 'period_min_dd':
+    elif ensembling_model == 'det_min_dd':
+        to_apply = lambda my_df : pd.DataFrame(my_df).fillna(0)
+        w_mat_predictors_list = list(map(to_apply, w_mat_predictors_list))
+        idx = w_mat_predictors_list[0].index
+        cols = w_mat_predictors_list[0].columns
+        w_mat = pd.DataFrame(index=idx, columns=cols)
+        #w_mat = pd.DataFrame(index=idx, columns=w_mat_target.columns)
+        portfolio = pd.Series(100., index=idx, name='portfolio')
+        print('rolling with past calibration size '+str(n))
+        print('rolling with rebalancing size '+str(s))
+
+        roll = rolling._EnsemblingRollingMechanism(idx, n=n, s=s)
+        for slice_n, slice_s, _ in roll():
+
+            if display_slice:
+                print('training slice '+str(slice_n))
+                print('testing slice '+str(slice_s))
+
+            train_ret = X_.loc[slice_n].copy()
+            #train_forward_looking = w_mat_target.loc[slice_n].copy()
+            #test_forward_looking = w_mat_target.loc[slice_s].copy()
+
+            to_train = lambda my_df: my_df.loc[slice_n].copy()
+            to_test = lambda my_df: my_df.loc[slice_s].copy()
+
+            train_weights = list(map(to_train, w_mat_predictors_list))
+            test_weights = list(map(to_test, w_mat_predictors_list))
+
+            #x = metrics.find_best_sharpe(train_weights, train_ret)
+            x = metrics.find_best_dd_weights(train_weights, train_ret)
+
+            if display_slice:
+                print('optimal weights found')
+                print(x)
+
+            pred_y = metrics.compute_average_prediction(x, test_weights)
+            pred_y = pred_y.fillna(0)
+            w_mat.loc[slice_s] = pred_y.values
+            #w_mat.loc[ensembled_weights_df_bis.index, assets] = ensembled_weights_df_bis.values
+            w = w_mat.loc[roll.d, :].fillna(0.)
+            # Compute portfolio performance
+            perf = _perf_alloc(
+                X.loc[slice_s, :].fillna(method='bfill').fillna(0.00000000001).values,
+                w=w,
+                drift=True
+            )
+            portfolio.loc[slice_s] = portfolio.loc[roll.d] * perf.flatten()
+        w_mat = w_mat.fillna(method='ffill').fillna(0.)
+        return portfolio, w_mat
+    elif ensembling_model == 'det_max_perf':
+        to_apply = lambda my_df : pd.DataFrame(my_df).fillna(0)
+        w_mat_predictors_list = list(map(to_apply, w_mat_predictors_list))
+        idx = w_mat_predictors_list[0].index
+        cols = w_mat_predictors_list[0].columns
+        w_mat = pd.DataFrame(index=idx, columns=cols)
+        #w_mat = pd.DataFrame(index=idx, columns=w_mat_target.columns)
+        portfolio = pd.Series(100., index=idx, name='portfolio')
+        print('rolling with past calibration size '+str(n))
+        print('rolling with rebalancing size '+str(s))
+
+        roll = rolling._EnsemblingRollingMechanism(idx, n=n, s=s)
+        for slice_n, slice_s, _ in roll():
+
+            if display_slice:
+                print('training slice '+str(slice_n))
+                print('testing slice '+str(slice_s))
+
+            train_ret = X_.loc[slice_n].copy()
+            #train_forward_looking = w_mat_target.loc[slice_n].copy()
+            #test_forward_looking = w_mat_target.loc[slice_s].copy()
+
+            to_train = lambda my_df: my_df.loc[slice_n].copy()
+            to_test = lambda my_df: my_df.loc[slice_s].copy()
+
+            train_weights = list(map(to_train, w_mat_predictors_list))
+            test_weights = list(map(to_test, w_mat_predictors_list))
+
+            #x = metrics.find_best_sharpe(train_weights, train_ret)
+            x = metrics.find_best_perf_weights(train_weights, train_ret)
+
+            if display_slice:
+                print('optimal weights found')
+                print(x)
+
+            pred_y = metrics.compute_average_prediction(x, test_weights)
+            pred_y = pred_y.fillna(0)
+            w_mat.loc[slice_s] = pred_y.values
+            #w_mat.loc[ensembled_weights_df_bis.index, assets] = ensembled_weights_df_bis.values
+            w = w_mat.loc[roll.d, :].fillna(0.)
+            # Compute portfolio performance
+            perf = _perf_alloc(
+                X.loc[slice_s, :].fillna(method='bfill').fillna(0.00000000001).values,
+                w=w,
+                drift=True
+            )
+            portfolio.loc[slice_s] = portfolio.loc[roll.d] * perf.flatten()
+        w_mat = w_mat.fillna(method='ffill').fillna(0.)
+        return portfolio, w_mat
+    elif ensembling_model == 'period_max_perf':
         starting_date = kwargs['starting_date']
         ending_date = kwargs['ending_date']
         index_tmp = w_mat_predictors_list[0].index
@@ -905,7 +1006,7 @@ def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=T
         print('number of weights configuration')
         print(len(w_mat_predictors_list))
         print('optimizing')
-        optimal_weights = metrics.find_best_perf_weights(X_filtered, filtered_w_mat_predictors_list)
+        optimal_weights = metrics.find_best_perf_weights(filtered_w_mat_predictors_list,X_filtered)
 
 
         print('optimal weights found')
