@@ -149,25 +149,69 @@ def generate_fourier_wvt_ortho_decomposition(lookback_windows,n_harms,fft_filter
                                     })
     return parameters
 
-def generate_kalman(lookback_windows,contravariants,n_harms,fft_filter_types,thresholds,obs_covs):
+# def generate_kalman(lookback_windows,contravariants,n_harms,fft_filter_types,thresholds,obs_covs):
+#     parameters = []
+#     for lookback_window in lookback_windows:
+#         for contravariant in contravariants:
+#             for fft_filter_type in fft_filter_types:
+#                 for n_harm in n_harms:
+#                     for threshold in thresholds:
+#                         for observation_covariance in obs_covs:
+#                             if n_harm < lookback_window:
+#                                 parameters.append({
+#                                     'lookback_window':lookback_window,
+#                                     'contravariant':contravariant,
+#                                     'fft_filter_type':fft_filter_type,
+#                                     'n_harm':n_harm,
+#                                     'threshold':threshold,
+#                                     'observation_covariance':observation_covariance
+#                                 })
+#     return parameters
+
+
+def generate_kalman(lookback_windows,contravariants,n_harms,fft_filter_types,obs_covs):
     parameters = []
     for lookback_window in lookback_windows:
         for contravariant in contravariants:
             for fft_filter_type in fft_filter_types:
                 for n_harm in n_harms:
-                    for threshold in thresholds:
-                        for observation_covariance in obs_covs:
-                            if n_harm < lookback_window:
-                                parameters.append({
-                                    'lookback_window':lookback_window,
-                                    'contravariant':contravariant,
-                                    'fft_filter_type':fft_filter_type,
-                                    'n_harm':n_harm,
-                                    'threshold':threshold,
-                                    'observation_covariance':observation_covariance
-                                })
+                    for observation_covariance in obs_covs:
+                        if n_harm < lookback_window:
+                            parameters.append({
+                                'lookback_window':lookback_window,
+                                'contravariant':contravariant,
+                                'fft_filter_type':fft_filter_type,
+                                'n_harm':n_harm,
+                                'observation_covariance':observation_covariance
+                            })
     return parameters
 
+
+
+def generate_fourier_hht(lookback_windows,contravariants,n_harms,fft_filter_types, threshold_1_values, threshold_2_values, alpha_values, n_imfs_values):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for contravariant in contravariants:
+            for fft_filter_type in fft_filter_types:
+                for n_harm in n_harms:
+                    for threshold_1 in threshold_1_values:
+                        for threshold_2 in threshold_2_values:
+                            for alpha in alpha_values:
+                                for n_imfs in n_imfs_values:
+                                    if n_harm < lookback_window:
+                                        parameters.append({
+                                            'lookback_window': lookback_window,
+                                            'contravariant': contravariant,
+                                            'fft_filter_type': fft_filter_type,
+                                            'n_harm': n_harm,
+                                            'threshold_1':threshold_1,
+                                            'threshold_2':threshold_2,
+                                            'alpha':alpha,
+                                            'n_imfs':n_imfs
+                                        })
+    return parameters
+
+
 def generate_fourier_decomposition(lookback_windows,contravariants,n_harms,fft_filter_types,):
     parameters = []
     for lookback_window in lookback_windows:
@@ -264,6 +308,23 @@ def generate_alpha_16_ls(lookback_windows, contravariants, lags, up_thresholds,
                                 'contravariant':contravariant
                             })
     return parameters
+
+def generate_alpha_6_ls(lookback_windows, vol_thresholds, contravariants, lags, display):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for contravariant in contravariants:
+            for vol_threshold in vol_thresholds:
+                for lag in lags:
+                    if lag <= int(lookback_window/2):
+                        parameters.append({
+                            'lookback_window':lookback_window,
+                            'contravariant':contravariant,
+                            'vol_threshold':vol_threshold,
+                            'lag':lag,
+                            'display' : display
+                        })
+    return parameters
+
 def generate_volume_weighted_high_low_vol_lo(lookback_windows, vol_thresholds, up_trend_thresholds, contravariants, lags, display):
     parameters = []
     for lookback_window in lookback_windows:
