@@ -8,6 +8,7 @@ from napoleontoolbox.tools.analyze_tools import roll_corr
 from scipy import stats
 from numpy import fft
 from pykalman import KalmanFilter
+from pyhht.emd import EMD
 import pywt
 import random
 from scipy.ndimage.interpolation import shift
@@ -131,7 +132,7 @@ def alpha_5_lo(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, contrav
 
 
 
-def alpha_5_ls(data = None, vol_threshold = 0.8, low_trend_threshold =0.2, up_trend_threshold=0.8, contravariant = -1., lag = 2, **kwargs):
+def alpha_5_ls(data = None, vol_threshold = 0.8, contravariant = -1., lag = 2, **kwargs):
     ## aggregating the volumes by lag
     data.index = range(0,len(data))
     all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
@@ -228,7 +229,7 @@ def alpha_6_lo(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, contrav
     else :
         return np.nan
 
-def alpha_6_ls(data = None, vol_threshold = 0.8, low_trend_threshold =0.2, up_trend_threshold=0.8, contravariant = -1., lag = 2, **kwargs):
+def alpha_6_ls(data = None, vol_threshold = 0.8, contravariant = -1., lag = 2, **kwargs):
     ## aggregating the volumes by lag
     data.index = range(0,len(data))
     all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
@@ -1250,10 +1251,10 @@ def select_orthogonal_coef(wtmra, coeff_index_factor, independent_selection):
         if independent_selection:
             return sum(independent_ortho_coeff)
         else:
-            non_independent_indexes = sum(independent_ortho_index)
-            non_independent_indexes[non_independent_indexes != 0] = 1
-            non_independent_ortho_coeff = sum(wtmra)*non_independent_indexes
-            return non_independent_ortho_coeff
+            non_independent_index = sum(independent_ortho_index)
+            non_independent_index[non_independent_index != 0] = 1
+            non_independent_ortho_coeff = wtmra*non_independent_index
+            return sum(non_independent_ortho_coeff)
 
 def is_discrete(wavelet_to_check, discrete):
     prefix_size = len(wavelet_to_check)
@@ -1267,7 +1268,7 @@ def set_wavelet_filters(kind='discrete'):
     for wavelet in wavelet_families:
         if is_discrete(wavelet, discrete_wavelets):
             selected_filters.append(random.choice(pywt.wavelist(family=wavelet, kind=kind)))
-    return selected_filters
+    return random.choices(selected_filters, k=3)
 
 def fourier_wvt_decompo_lo(data=None, filter_name='haar', contravariant=1., dec_level=2, n_harm=5, fft_filter_type='low', optimize_filtering = True, threshold=0.7, soft_filtering = True, **kwargs):
     n_predict = 1
@@ -1406,4 +1407,42 @@ def kalman_filtering_lo(data=None, observation_covariance=0.01, contravariant=1,
         else:
             return np.nan
     except:
-        return np.nan
\ No newline at end of file
+        return np.nan
+
+def fourier_hht_ls(data=None, threshold_1=0.05, threshold_2=0.5, alpha=0.05, n_imfs=2,
+                           n_harm=5, fft_filter_type='low', contravariant=1, **kwargs):
+    n_predict = 1
+    try:
+        cur_df = data.copy()
+        x = cur_df['close'].values
+        last_available_close = x[-1]
+        decomposer = EMD(x, threshold_1=threshold_1, threshold_2=threshold_2, alpha=alpha, n_imfs=n_imfs)
+        imfs = decomposer.decompose()
+        approx = x - sum(imfs[:-1])
+        lb_signal = fourier_extrapolation(approx, n_predict, n_harm, fft_filter_type)
+        next_close = lb_signal[0]
+        test = contravariant * np.sign(next_close - last_available_close)
+        return test
+    except:
+        return np.nan
+
+
+def fourier_hht_lo(data=None, threshold_1=0.05, threshold_2=0.5, alpha=0.05, n_imfs=2,
+                   n_harm=5, fft_filter_type='low', contravariant=1, **kwargs):
+    n_predict = 1
+    try:
+        cur_df = data.copy()
+        x = cur_df['close'].values
+        last_available_close = x[-1]
+        decomposer = EMD(x, threshold_1=threshold_1, threshold_2=threshold_2, alpha=alpha, n_imfs=n_imfs)
+        imfs = decomposer.decompose()
+        approx = x - sum(imfs[:-1])
+        lb_signal = fourier_extrapolation(approx, n_predict, n_harm, fft_filter_type)
+        next_close = lb_signal[0]
+        test = contravariant * np.sign(next_close - last_available_close)
+        if test > 0:
+            return 1
+        else:
+            return np.nan
+    except:
+        return np.nan
