@@ -75,7 +75,7 @@ def roll(df, w):
     })
     return rolled_df.groupby(level=0)
 
-def f_sharpe_signals_mix(data, w, display_threshold = 0.99):
+def f_sharpe_signals_mix(data, w, display_threshold = 0.99, period = 252):
     all_signals = [col for col in data.columns if 'signal' in col]
     N_ = len(all_signals)
     w = w.reshape([1,N_])
@@ -83,8 +83,8 @@ def f_sharpe_signals_mix(data, w, display_threshold = 0.99):
     #temp_df = temp_df.rename(columns={"signal0": "signal"}, errors="raise")
     tt = pd.DataFrame(data[all_signals].values * w, columns=all_signals, index=data.index)
     temp_df['signal'] = tt.sum(axis=1)
-    hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, print_turnover=False)
-    sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
+    freqly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, print_turnover=False)
+    sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period= period, from_ret=True)
     if np.random.rand()>display_threshold:
         print(w)
         print('signals mix sharpe')
@@ -106,6 +106,24 @@ def expanding_zscore(signal_np_array=None, skipping_point = 5, signal_continuum_
     else:
         raise Exception('zscoring a non continuous signal '+str(nb_distinct_signals))
 
+
+def compute_signal_perf_ind(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True):
+
+    data['turn_over'] = abs(data['signal'] - data['signal'].shift(-1).fillna(0.))
+    average_turn_over = data['turn_over'].sum() / len(data)
+
+    data['close_return'] = data['close'].pct_change()
+    data['reconstituted_close'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
+
+    data['non_adjusted_perf_return'] = data['close_return'] * data['signal']
+    data['adjusted°perf_return'] = data['non_adjusted_perf_return'] - data['turn_over'] * average_execution_cost
+
+    data['non_adjusted_reconstituted_perf'] = metrics.from_ret_to_price(data['non_adjusted_perf_return'],initial_price=initial_price)
+    perf_under = (data['reconstituted_close'].iloc[-1] - 1.) / 1.
+    perf_strat = (data['non_adjusted_reconstituted_perf'].iloc[-1] - 1.) / 1.
+    return average_turn_over, perf_under, perf_strat
+
+
 def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False, normalization = False):
     if normalization:
         #data.signal = (data.signal - data.signal.mean())/data.signal.std(ddof=0)
@@ -181,7 +199,7 @@ def optimize_weights(data = None, starting_date = None, ending_date = None):
     print(w__)
     return w__
 
-def compute_signals_weights_perf(data = None, optimal_weights = None, starting_date = None, ending_date = None, normalization = False, n_items_per_year = 252):
+def compute_signals_weights_perf(data = None, optimal_weights = None, starting_date = None, ending_date = None, normalization = False, period = 252):
     print(max(data.index))
     print(min(data.index))
     data = data[data.index >= starting_date]
@@ -190,14 +208,17 @@ def compute_signals_weights_perf(data = None, optimal_weights = None, starting_d
     print(min(data.index))
     all_sigs = [col for col in data.columns if 'signal' in col]
     temp_df = data[['close']].copy()
+    if optimal_weights is None:
+        N_ = len(all_sigs)
+        optimal_weights = np.ones([N_]) / N_
     #temp_df = temp_df.rename(columns={"signal0": "signal"}, errors="raise")
     optimal_signal = pd.DataFrame(data[all_sigs].values * optimal_weights, columns=all_sigs, index=data.index)
     temp_df['signal'] = optimal_signal.sum(axis=1)
     hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=False, normalization=normalization)
-    sharpe_strat_without = metrics.sharpe(hourly_df['perf_return'].dropna(), period=n_items_per_year, from_ret=True)
-    sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period=n_items_per_year, from_ret=True)
+    sharpe_strat_without = metrics.sharpe(hourly_df['perf_return'].dropna(), period=period, from_ret=True)
+    sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period=period, from_ret=True)
 
     hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, normalization=normalization)
-    sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=n_items_per_year, from_ret=True)
+    sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=period, from_ret=True)
     return hourly_df, sharpe_strat, sharpe_strat_without, sharpe_under
 
